@@ -18,25 +18,27 @@ class Validator(Validator):
         if cin:
             pass
 
+def gotit(resource, request, response=None):
+
+    print 'get', resource
+    print request
+    print response
+
+def resource_gotit(request, response):
+    print 'get_contacts'
+    print request.data
+    print response.data
+
+def resource_post(request, response):
+    print 'post_contacts'
+    print request
+    print response
+
 app = Eve(validator=Validator)
-
-@app.before_request
-def br():
-    try:
-        print "br"
-        print request
-    except:
-        pass
-
-@app.after_request
-def ar(arg):
-    try:
-        print "ar"
-        print arg
-    except:
-        pass
-    return arg
-
+#app.config['DOMAIN']['contacts']['auth_username_field'] = 'name'
+#app.on_get_contacts += resource_gotit
+#app.on_get += gotit
+#app.on_post_contacts += resource_post
 
 if __name__ == '__main__':
     #app.events.on_getting += pre
